/* vi: set et sw=4 ts=4 cino=t0,(0: */
/* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of osso-accounts
 *
 * Copyright (C) 2007 Nokia Corporation. All rights reserved.
 *
 * Contact: Alberto Mardegan <alberto.mardegan@nokia.com>
 * Contact: Lassi Syrjala <lassi.syrjala@nokia.com>
 *
 * This software, including documentation, is protected by copyright controlled
 * by Nokia Corporation. All rights are reserved.
 * Copying, including reproducing, storing, adapting or translating, any or all
 * of this material requires the prior written consent of Nokia Corporation.
 * This material also contains confidential information which may not be
 * disclosed to others without the prior written consent of Nokia.
 */

#ifndef _RTCOM_ACCOUNT_PLUGIN_H_
#define _RTCOM_ACCOUNT_PLUGIN_H_

#include <libaccounts/account-plugin.h>
#include <libmissioncontrol/mc-profile.h>
#include <libmissioncontrol/mc-account-monitor.h>
#include <libmissioncontrol/mission-control.h>


G_BEGIN_DECLS

#define RTCOM_TYPE_ACCOUNT_PLUGIN             (rtcom_account_plugin_get_type ())
#define RTCOM_ACCOUNT_PLUGIN(obj)             (G_TYPE_CHECK_INSTANCE_CAST ((obj), RTCOM_TYPE_ACCOUNT_PLUGIN, RtcomAccountPlugin))
#define RTCOM_ACCOUNT_PLUGIN_CLASS(klass)     (G_TYPE_CHECK_CLASS_CAST ((klass), RTCOM_TYPE_ACCOUNT_PLUGIN, RtcomAccountPluginClass))
#define RTCOM_IS_ACCOUNT_PLUGIN(obj)          (G_TYPE_CHECK_INSTANCE_TYPE ((obj), RTCOM_TYPE_ACCOUNT_PLUGIN))
#define RTCOM_IS_ACCOUNT_PLUGIN_CLASS(klass)  (G_TYPE_CHECK_CLASS_TYPE ((klass), RTCOM_TYPE_ACCOUNT_PLUGIN))
#define RTCOM_ACCOUNT_PLUGIN_GET_CLASS(obj)   (G_TYPE_INSTANCE_GET_CLASS ((obj), RTCOM_TYPE_ACCOUNT_PLUGIN, RtcomAccountPluginClass))

typedef struct _RtcomAccountPluginClass RtcomAccountPluginClass;
typedef struct _RtcomAccountPlugin RtcomAccountPlugin;

#include "rtcom-context.h"

struct _RtcomAccountPluginClass
{
    AccountPluginClass parent_class;
    void (*context_init) (RtcomAccountPlugin *plugin, RtcomContext *context);
};

struct _RtcomAccountPlugin
{
    AccountPlugin parent_instance;

    /*< protected >*/
    GHashTable *profiles;
    /* The name must be set in the instance init function of the derived class */
    gchar *name;

    McAccountMonitor *monitor;
    MissionControl *mission_control;

    DBusGConnection *dbus_conn;
};

GType rtcom_account_plugin_get_type (void) G_GNUC_CONST;

guint rtcom_account_plugin_get_mc_account_status (RtcomAccountPlugin *plugin,
                                                  McAccount *account);

void rtcom_account_plugin_add_service (RtcomAccountPlugin *plugin,
                                       const gchar *name);

G_END_DECLS

#endif /* _RTCOM_ACCOUNT_PLUGIN_H_ */
